@@ -4,7 +4,6 @@ Workflow which exercises the common tasks in an end to end scenario
 from dkist_processing_common.tasks import AddDatasetReceiptAccount
 from dkist_processing_common.tasks import PublishCatalogAndQualityMessages
 from dkist_processing_common.tasks import QualityL1Metrics
-from dkist_processing_common.tasks import SubmitQuality
 from dkist_processing_common.tasks import Teardown
 from dkist_processing_common.tasks import TransferL0Data
 from dkist_processing_common.tasks import TransferL1Data
@@ -15,6 +14,7 @@ from dkist_processing_test.tasks.movie import AssembleTestMovie
 from dkist_processing_test.tasks.movie import MakeTestMovieFrames
 from dkist_processing_test.tasks.parse import ParseL0TestInputData
 from dkist_processing_test.tasks.quality import TestQualityL0Metrics
+from dkist_processing_test.tasks.quality import TestSubmitQuality
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
 # TransferInputData Task
@@ -60,7 +60,7 @@ quality_submit_metrics = Workflow(
     workflow_package=__package__,
     tags=["test"],
 )
-quality_submit_metrics.add_node(task=SubmitQuality, upstreams=None)
+quality_submit_metrics.add_node(task=TestSubmitQuality, upstreams=None)
 
 # GenerateL1CalibratedData Task
 generate_calibrated_data = Workflow(
